@@ -24,6 +24,7 @@
 #' \describe{
 #'  \item{nobs}{Sample size. The number of rows in the dataset.}
 #'  \item{testlength}{Length of the test. The number of items included in the test.}
+#'  \item{msg}{A character string indicating the model type. }
 #'  \item{Nclass}{Optimal number of classes.}
 #'  \item{Nfield}{Optimal number of fields.}
 #'  \item{crr}{Correct Response Rate}
@@ -391,6 +392,7 @@ LDB <- function(U, Z = NULL, w = NULL, na = NULL,
   ret <- structure(list(
     U = U,
     testlength = testlength,
+    msg = "Rank",
     nobs = nobs,
     Nrank = ncls,
     Nfield = nfld,
