@@ -26,6 +26,7 @@
 #' @return
 #' \describe{
 #'  \item{nobs}{Sample size. The number of rows in the dataset.}
+#'  \item{msg}{A character string indicating the model type. }
 #'  \item{testlength}{Length of the test. The number of items included in the test.}
 #'  \item{Nclass}{Optimal number of classes.}
 #'  \item{Nfield}{Optimal number of fields.}
@@ -523,6 +524,7 @@ BINET <- function(U, Z = NULL, w = NULL, na = NULL,
   ret <- structure(list(
     U = U,
     testlength = testlength,
+    msg = "Rank",
     nobs = nobs,
     Nclass = ncls,
     Nfield = nfld,
